# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------
from azdata.cli.core.deploy import DeploymentConfigUtil
from azdata.cli.commands.bdc.constants import CONFIG_DIR


def load_arguments(self, _):
    from knack.arguments import ArgumentsContext
    from azdata.cli.commands.bdc import _

    with ArgumentsContext(self, 'bdc create') as arg_context:
        arg_context.argument(
            'name',
            options_list=('--name', '-n'),
            help=_('Big data cluster name, used for kubernetes namespaces.')
        )

        arg_context.argument(
            'config_profile',
            options_list=('--config-profile', '-c'),
            help=_('Big data cluster config profile, used for deploying the cluster: {0}').format(
                list(DeploymentConfigUtil.get_config_map(CONFIG_DIR).keys()))
        )

        arg_context.argument(
            'accept_eula',
            options_list=('--accept-eula', '-a'),
            help='Do you accept the license terms? [yes/no]. If you do not want to use this arg, '
                 'you may set the environment variable ACCEPT_EULA to \'yes\'. The license terms for azdata can '
                 'be viewed at https://aka.ms/eula-azdata-en.'
        )

        arg_context.argument(
            'node_label',
            options_list=('--node-label', '-l'),
            help=_('Big data cluster node label, used to designate what nodes to deploy to.')
        )

        arg_context.argument(
            'force',
            options_list=('--force', '-f'),
            action='store_true',
            help=_('Force create, the user will not be prompted for any values and all issues will be printed as part'
                   'of stderr.')
        )

    with ArgumentsContext(self, 'bdc delete') as arg_context:
        arg_context.argument(
            'name',
            options_list=('--name', '-n'),
            help=_('Big data cluster name, used for kubernetes namespace.')
        )

        arg_context.argument(
            'force',
            options_list=('--force', '-f'),
            action='store_true',
            help=_('Force delete big data cluster.')
        )

    with ArgumentsContext(self, 'bdc upgrade') as arg_context:
        arg_context.argument(
            'name',
            options_list=('--name', '-n'),
            help=_('Big data cluster name, used for kubernetes namespaces.')
        )

        arg_context.argument(
            'target_version',
            options_list=('--tag', '-t'),
            help=_('The target docker image tag to upgrade all container in the cluster to.')
        )

        arg_context.argument(
            'target_repository',
            options_list=('--repository', '-r'),
            help=_('The docker repository to have all containers in the cluster pull their images from.')
        )

        arg_context.argument(
            'controller_timeout',
            options_list=('--controller-timeout', '-k'),
            help=_('The number of minutes to wait for the controller or controller database to upgrade '
                    'before rolling back the upgrade.')
        )

        arg_context.argument(
            'stability_threshold',
            options_list=('--stability-threshold', '-s'),
            help=_('The number of minutes to wait after an upgrade before marking it as stable.')
        )

        arg_context.argument(
            'component_timeout',
            options_list=('--component-timeout', '-p'),
            help=_('The number of minutes to wait for each phase of the upgrade (after controller upgrade) '
                    'to complete before pausing the upgrade.')
        )

    with ArgumentsContext(self, 'bdc config init') as arg_context:
        arg_context.argument(
            'source',
            options_list=('--source', '-s'),
            help=_('Config profile source: {0}').format(
                list(DeploymentConfigUtil.get_config_map(CONFIG_DIR).keys()))
        )

        arg_context.argument(
            'target',
            options_list=
            [
                '--path',
                '-p',
                arg_context.deprecate(
                    target='-t',
                    redirect='-p',
                    hide=False
                ),
                arg_context.deprecate(
                    target='--target',
                    redirect='--path',
                    hide=False
                )
            ],
            help=_('File path of where you would like the config profile placed, defaults to <cwd>/custom.')
        )

        arg_context.argument(
            'force',
            options_list=('--force', '-f'),
            action='store_true',
            help=_('Force overwrite of the target file.')
        )

        arg_context.argument(
            'accept_eula',
            options_list=('--accept-eula', '-a'),
            help='Do you accept the license terms? [yes/no]. If you do not want to use this arg, '
                 'you may set the environment variable ACCEPT_EULA to \'yes\'. The license terms for this product can '
                 'be viewed at https://aka.ms/eula-azdata-en.'
        )

    with ArgumentsContext(self, 'bdc status show') as arg_context:
        arg_context.argument(
            'resource',
            options_list=('--resource', '-r'),
            help=_('Get the services associated with this resource.')
        )

        arg_context.argument(
            'all',
            options_list=('--all', '-a'),
            action='store_true',
            help=_('Show all the instances of each resource within the services.')
        )

    with ArgumentsContext(self, 'bdc control status show') as arg_context:
        arg_context.argument(
            'resource',
            options_list=('--resource', '-r'),
            help=_('Get this resource in this service.')
        )

        arg_context.argument(
            'all',
            options_list=('--all', '-a'),
            action='store_true',
            help=_('Show all the instances of each resource within the service.'))

    with ArgumentsContext(self, 'bdc sql status show') as arg_context:
        arg_context.argument(
            'resource',
            options_list=('--resource', '-r'),
            help=_('Get this resource in this service.')
        )

        arg_context.argument(
            'all',
            options_list=('--all', '-a'),
            action='store_true',
            help=_('Show all the instances of each resource within the service.'))

    with ArgumentsContext(self, 'bdc hdfs status show') as arg_context:
        arg_context.argument(
            'resource',
            options_list=('--resource', '-r'),
            help=_('Get this resource in this service.')
        )

        arg_context.argument(
            'all',
            options_list=('--all', '-a'),
            action='store_true',
            help=_('Show all the instances of each resource within the service.'))

    with ArgumentsContext(self, 'bdc spark status show') as arg_context:
        arg_context.argument(
            'resource',
            options_list=('--resource', '-r'),
            help=_('Get this resource in this service.')
        )

        arg_context.argument(
            'all',
            options_list=('--all', '-a'),
            action='store_true',
            help=_('Show all the instances of each resource within the service.'))

    with ArgumentsContext(self, 'bdc gateway status show') as arg_context:
        arg_context.argument(
            'resource',
            options_list=('--resource', '-r'),
            help=_('Get this resource in this service.')
        )

        arg_context.argument(
            'all',
            options_list=('--all', '-a'),
            action='store_true',
            help=_('Show all the instances of each resource within the service.'))

    with ArgumentsContext(self, 'bdc app status show') as arg_context:
        arg_context.argument(
            'resource',
            options_list=('--resource', '-r'),
            help=_('Get this resource in this service.')
        )

        arg_context.argument(
            'all',
            options_list=('--all', '-a'),
            action='store_true',
            help=_('Show all the instances of each resource within the service.'))

    with ArgumentsContext(self, 'bdc config add') as arg_context:
        arg_context.argument(
            'config_file',
            options_list=
            [
                '--path',
                '-p',
                arg_context.deprecate(
                    target='-c',
                    redirect='-p',
                    hide=False
                ),
                arg_context.deprecate(
                    target='--config-file',
                    redirect='--path',
                    hide=False
                )
            ],
            help=_('Big data cluster config file path of the config you would like to set, i.e. custom/bdc.json')
        )

        arg_context.argument(
            'json_values',
            options_list=('--json-values', '-j'),
            help=_('A key value pair list of json paths to values: key1.subkey1=value1,key2.subkey2=value2. '
                   'You may provide inline json values such as: '
                   'key=\'{\"kind\":\"cluster\",\"name\":\"test-cluster\"}\' or provide a file path, such as'
                   ' key=./values.json. Add does NOT support conditionals.  '
                   'If the inline value you are providing is a key '
                   'value pair itself with \'=\' and \',\' please escape those characters.  '
                   'For example, key1="key2\=val2\,key3\=val3". '
                   'Please see http://jsonpatch.com/ for '
                   'examples of how your path should look.  If you would like to access an array, you must do so '
                   'by indicating the index, such as key.0=value')
        )

    with ArgumentsContext(self, 'bdc config replace') as arg_context:
        arg_context.argument(
            'config_file',
            options_list=
            [
                '--path',
                '-p',
                arg_context.deprecate(
                    target='-c',
                    redirect='-p',
                    hide=False
                ),
                arg_context.deprecate(
                    target='--config-file',
                    redirect='--path',
                    hide=False
                )
            ],
            help=_('Big data cluster config file path of the config you would like to set, i.e. custom/bdc.json')
        )

        arg_context.argument(
            'json_values',
            options_list=('--json-values', '-j'),
            help=_('A key value pair list of json paths to values: key1.subkey1=value1,key2.subkey2=value2. '
                   'You may provide inline json values such as: '
                   'key=\'{\"kind\":\"cluster\",\"name\":\"test-cluster\"}\' or provide a file path, such as'
                   ' key=./values.json. Replace supports conditionals through the jsonpath library.  To use this, '
                   'start your path with a $. This will allow you to do a conditional '
                   'such as -j $.key1.key2[?(@.key3==\'someValue\'].key4=value. '
                   'If the inline value you are providing is a key '
                   'value pair itself with \'=\' and \',\' please escape those characters.  '
                   'For example, key1="key2\=val2\,key3\=val3". '
                   'You may see examples below. '
                   'For additional help, please see: https://jsonpath.com/')
        )

    with ArgumentsContext(self, 'bdc config remove') as arg_context:
        arg_context.argument(
            'config_file',
            options_list=
            [
                '--path',
                '-p',
                arg_context.deprecate(
                    target='-c',
                    redirect='-p',
                    hide=False
                ),
                arg_context.deprecate(
                    target='--config-file',
                    redirect='--path',
                    hide=False
                )
            ],
            help=_('Big data cluster config file path of the config you would like to set, i.e. custom/bdc.json')
        )

        arg_context.argument(
            'json_path',
            options_list=('--json-path', '-j'),
            help=_('A list of json paths based on the jsonpatch library that indicates which values you would like '
                   'removed, such as: key1.subkey1,key2.subkey2. Remove does NOT support conditionals. '
                   'Please see http://jsonpatch.com/ for '
                   'examples of how your path should look.  If you would like to access an array, you must do so '
                   'by indicating the index, such as key.0=value')
        )

    with ArgumentsContext(self, 'bdc config patch') as arg_context:
        arg_context.argument(
            'config_file',
            options_list=
            [
                '--path',
                arg_context.deprecate(
                    target='-c',
                    redirect='--path',
                    hide=False
                ),
                arg_context.deprecate(
                    target='--config-file',
                    redirect='--path',
                    hide=False
                )
            ],
            help=_('Big data cluster config file path of the config you would like to set, i.e. custom/bdc.json')
        )

        arg_context.argument(
            'patch_file',
            options_list=('--patch-file', '-p'),
            help=_('Path to a patch json file that is based off the jsonpatch library: http://jsonpatch.com/. '
                   'You must start your patch json file with a key called "patch", whose value is an array '
                   'of patch operations you intend to make. '
                   'For the path of a patch operation, you may use dot notation, such as key1.key2 for most operations.'
                   ' If you would like to do a replace operation, and you are replacing a value in an array that '
                   'requires a conditional, please use the jsonpath notation by beginning your path with a $. '
                   'This will allow you to do a conditional such as $.key1.key2[?(@.key3==\'someValue\'].key4. '
                   'Please see the examples below. For additional help with conditionals, '
                   'please see: https://jsonpath.com/.')
        )

    with ArgumentsContext(self, 'bdc config list') as arg_context:
        arg_context.argument(
            'config_profile',
            options_list=('--config-profile', '-c'),
            help=_('Default config profile: {0}').format(
                list(DeploymentConfigUtil.get_config_map(CONFIG_DIR).keys()))
        )

        arg_context.argument(
            'config_type',
            options_list=('--type', '-t'),
            choices=('bdc', 'control'),
            help=_('What config type you would like to see.')
        )

        arg_context.argument(
            'accept_eula',
            options_list=('--accept-eula', '-a'),
            help='Do you accept the license terms? [yes/no]. If you do not want to use this arg, '
                 'you may set the environment variable ACCEPT_EULA to \'yes\'. The license terms for this product can '
                 'be viewed at https://aka.ms/eula-azdata-en.'
        )

    with ArgumentsContext(self, 'bdc config show') as arg_context:
        arg_context.argument(
            'target',
            options_list=('--target', '-t'),
            help=_('Output file to store the result in. Default: directed to '
                   'stdout.')
        )

        arg_context.argument(
            'json_path',
            options_list=('--json-path', '-j'),
            help=_(
                'The json key path that leads to the section or value you want from the config, '
                'i.e. key1.key2.key3. Uses the jsonpath query language, https://jsonpath.com/, '
                'for example: -j \'$.spec.pools[?(@.spec.type == \"Master\")]..endpoints\'')
        )

        arg_context.argument(
            'config_file',
            options_list=('--config-file', '-c'),
            help=_('Big data cluster config file path if you don\'t want the config of the cluster you are currently'
                   'logged in to, i.e. custom/bdc.json')
        )

        arg_context.argument(
            'force',
            options_list=('--force', '-f'),
            action='store_true',
            help=_('Force overwrite of the target file.')
        )

    with ArgumentsContext(self, 'bdc endpoint list') as arg_context:
        arg_context.argument(
            'endpoint_name',
            options_list=('--endpoint-name', '-e'),
            help=_('Big data cluster endpoint name.')
        )

    with ArgumentsContext(self, 'bdc debug copy-logs') as arg_context:
        arg_context.argument(
            'namespace',
            options_list=
            [
                '--namespace',
                '-ns',
                arg_context.deprecate(
                    target='-n',
                    redirect='--namespace',
                    hide=False
                )
            ],
            help=_('Big data cluster name, used for kubernetes namespace.')
        )

        arg_context.argument(
            'target_folder',
            options_list=('--target-folder', '-d'),
            help=_('Target folder path to copy logs to. Optional, by default '
                   'creates the result in the local folder.  Cannot be specified '
                   'multiple times. If specified multiple times, last one will '
                   'be used')
        )

        arg_context.argument(
            'pod',
            options_list=('--pod', '-p'),
            help=_('Copy the logs for the pods with similar name. Optional, by '
                   'default copies logs for all pods. Cannot be specified '
                   'multiple times. If specified multiple times, last one will '
                   'be used')
        )

        arg_context.argument(
            'container',
            options_list=('--container', '-c'),
            help=_('Copy the logs for the containers with similar name, '
                   'Optional, by default copies logs for all containers. Cannot '
                   'be specified multiple times. If specified multiple times, '
                   'last one will be used')
        )

        arg_context.argument(
            'timeout',
            options_list=('--timeout', '-t'),
            type=int,
            default=0,
            help=_('The number of seconds to wait for the command to complete. '
                   'The default value is 0 which is unlimited')
        )

        arg_context.argument(
            'skip_compress',
            options_list=('--skip-compress', '-sc'),
            action='store_true',
            default=False,
            help=_('Whether or not to skip compressing the result folder. '
                   'The default value is False which compresses the result folder.')
        )

        arg_context.argument(
            'exclude_dumps',
            options_list=('--exclude-dumps', '-ed'),
            action='store_true',
            default=False,
            help=_('Whether or not to exclude dumps from result folder. '
                   'The default value is False which includes dumps.')
        )

    with ArgumentsContext(self, 'bdc debug dump') as arg_context:
        arg_context.argument(
            'namespace',
            options_list=
            [
                '--namespace',
                '-ns',
                arg_context.deprecate(
                    target='-n',
                    redirect='--namespace',
                    hide=False
                )
            ],
            help=_('Big data cluster name, used for kubernetes namespace.')
        )

        arg_context.argument(
            'container',
            options_list=('--container', '-c'),
            choices=['controller'],
            default='controller',
            help=_('The target container to be triggered for dumping the running processes')
        )

        arg_context.argument(
            'target_folder',
            options_list=('--target-folder', '-d'),
            default='./output/dump',
            help=_('Target folder to copy the dump out.')
        )
