# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------
from azdata.cli.core.commands import CliCommandGroup
from azdata.cli.commands.bdc.client import (
    beget,
    beget_no_check_auth,
    beget_no_check_auth_or_eula
)


def load_command_table(self, _):

    def hierarchical_output(command_result):
        """
        Callback for formatting complex custom-output.
        :parm_am command_result: The command's high-level result object.
        :return: Complex BoxLayout otherwise flat json.
        """
        from azdata.cli.core.layout import BoxLayout
        from azdata.cli.commands.bdc.util import order_status

        try:
            raw_result = command_result.result
            result = order_status('bdc')(raw_result)
            result = result if result else order_status('services')(raw_result)
            result = result if result else order_status('resources')(raw_result)

            return BoxLayout(result, config={
                'headers': {
                    'left': {
                        'label': '',
                        'id': 'state'
                    },
                    'right': {
                        'label': 'Health Status: ',
                        'id': 'healthStatus'
                    }
                },
                'identifiers': [
                    {'id': 'healthStatus', 'name': 'healthy',
                     'style': 'green'},
                    {'id': 'healthStatus', 'name': 'unhealthy',
                     'style': 'red', 'undesirable': True},
                    {'id': 'state', 'name': 'state', 'style': None}
                ]
            })
        except Exception as e:  # -- fallback --
            from knack.output import format_json
            return format_json(command_result)

    with CliCommandGroup(self, 'bdc',
                         'azdata.cli.commands.bdc.custom#{}',
                         client_factory=beget_no_check_auth_or_eula) as g:
        g.command('create', 'bdc_create')

    with CliCommandGroup(self, 'bdc',
                         'azdata.cli.commands.bdc.custom#{}',
                         client_factory=beget_no_check_auth) as g:
        g.command('delete', 'bdc_delete')

    with CliCommandGroup(self, 'bdc',
                         'azdata.cli.commands.bdc.custom#{}',
                         client_factory=beget) as g:
        g.command('upgrade', 'bdc_upgrade')

    with CliCommandGroup(self, 'bdc config',
                         'azdata.cli.commands.bdc.custom#{}',
                         client_factory=beget_no_check_auth_or_eula) as g:
        g.command('list', 'bdc_config_list')
        g.command('init', 'bdc_config_init')

    with CliCommandGroup(self, 'bdc config',
                         'azdata.cli.commands.bdc.custom#{}',
                         client_factory=beget_no_check_auth) as g:
        g.command('show', 'bdc_config_show')
        g.command('patch', 'bdc_config_patch')
        g.command('add', 'bdc_config_add')
        g.command('replace', 'bdc_config_replace')
        g.command('remove', 'bdc_config_remove')

    with CliCommandGroup(self, 'bdc debug',
                         'azdata.cli.commands.bdc.custom#{}',
                         client_factory=beget_no_check_auth) as g:
        g.command('copy-logs', 'bdc_debug_copy_logs')
        g.command('dump', 'bdc_debug_dump')

    with CliCommandGroup(self, 'bdc endpoint',
                         'azdata.cli.commands.bdc.custom#{}',
                         client_factory=beget) as g:
        g.command('list', 'bdc_endpoint')

    with CliCommandGroup(self, 'bdc status',
                         'azdata.cli.commands.bdc.custom#{}',
                         client_factory=beget) as g:
        g.command('show', 'bdc_status_show', output=hierarchical_output)

    with CliCommandGroup(self, 'bdc control status',
                         'azdata.cli.commands.bdc.custom#{}',
                         client_factory=beget) as g:
        g.command('show', 'bdc_control_status_show', output=hierarchical_output)

    with CliCommandGroup(self, 'bdc sql status',
                         'azdata.cli.commands.bdc.custom#{}',
                         client_factory=beget) as g:
        g.command('show', 'bdc_sql_status_show', output=hierarchical_output)

    with CliCommandGroup(self, 'bdc hdfs status',
                         'azdata.cli.commands.bdc.custom#{}',
                         client_factory=beget) as g:
        g.command('show', 'bdc_hdfs_status_show', output=hierarchical_output)

    with CliCommandGroup(self, 'bdc spark status',
                         'azdata.cli.commands.bdc.custom#{}',
                         client_factory=beget) as g:
        g.command('show', 'bdc_spark_status_show', output=hierarchical_output)

    with CliCommandGroup(self, 'bdc gateway status',
                         'azdata.cli.commands.bdc.custom#{}',
                         client_factory=beget) as g:
        g.command('show', 'bdc_gateway_status_show', output=hierarchical_output)

    with CliCommandGroup(self, 'bdc app status',
                         'azdata.cli.commands.bdc.custom#{}',
                         client_factory=beget) as g:
        g.command('show', 'bdc_app_status_show', output=hierarchical_output)
