from azdata.cli.core.models.custom_resource import CustomResource


class DataControllerCustomResource(CustomResource):
    """
    Internal Custom Resource object to be used for deployments.
    """
    def __init__(self, cr_object):
        super().__init__(cr_object)
        """
        Initializes a CR object with the given json.
        :param cr_object: The custom resource json.
        """

    @property
    def security(self):
        """
        Gets the cr security property
        """
        if "security" not in self.spec:
            return None
        else:
            return self.spec["security"]

    @property
    def phase(self):
        """
        Gets the phase of the status
        :return:
        """
        if self.status:
            return self.status.get("phase")
        else:
            return None

    @property
    def services(self):
        """
        Gets the services of the data controller custom resource.
        :return:
        """
        return self.spec.get("services")

    @property
    def controller_service(self):
        """
        Gets the controller service of the data controller custom resource.
        :return:
        """
        if self.services:
            for s in self.services:
                if s.get("name") == "controller":
                    return s
            return None
        else:
            return None

    @property
    def controller_service_port(self):
        """
        Gets the controller service port
        :return:
        """
        if self.controller_service:
            return self.controller_service.get("port")
        else:
            return None

    @property
    def controller_service_type(self):
        """
        Gets the controller service type
        :return:
        """
        if self.controller_service:
            return self.controller_service.get("serviceType")
        else:
            return None