# ------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ------------------------------------------------------------------------------


from pprint import pformat

try:
    from types import SimpleNamespace as Namespace
except ImportError:
    # Python 2.x fallback
    from argparse import Namespace

import json

# ---------------------------------------------------------------------------- #
# ---------------------------------------------------------------------------- #
# ---------------------------------------------------------------------------- #


class SwaggerNamespace(Namespace):
    def __init__(self, **kwargs):
        super(SwaggerNamespace, self).__init__(**kwargs)

# ---------------------------------------------------------------------------- #
# ---------------------------------------------------------------------------- #
# ---------------------------------------------------------------------------- #


class Swagger(object):
    """
    Represents the abstract swagger as a condensed namespace.
    """
    def __init__(self, swag):
        """
        The constructor for transforming a swagger dict into a namespace.
        :param swag: swagger document as a `dict`.
        """

        self._swag = json.loads(json.dumps(swag),
                                object_hook=lambda s: SwaggerNamespace(**s))

    def to_dict(self):
        """
         Returns the model properties as a dict.
        """
        return self._to_dict(self._swag)

    def to_str(self):
        """
        Returns the string representation of the model.
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`.
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal.
        """
        if not isinstance(other, Swagger):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal.
        """
        return not self == other

    def _to_dict(self, ns):
        results = dict()
        keys = sorted(ns.__dict__)
        for k in keys:
            v = ns.__dict__[k]
            if isinstance(v, SwaggerNamespace):
                v = self._to_dict(v)

            if isinstance(v, list):
                tmp = []
                for i in range(len(v)):
                    tmp.append(self._to_dict(v[i])
                               if isinstance(v[i], SwaggerNamespace)
                               else v[i])
                v = tmp

            results[k] = v

        return results
